# eric7.MicroPython.BluetoothDialogs.BluetoothScanWindow

Module implementing a dialog to scan for Bluetooth devices.

### Global Attributes

None

### Classes

BluetoothScanWindow | Class implementing a dialog to scan for Bluetooth devices.

### Functions

None

## BluetoothScanWindow

Class implementing a dialog to scan for Bluetooth devices.

### Derived from

QWidget, Ui_BluetoothScanWindow

### Class Attributes

None

### Class Methods

None

### Methods

BluetoothScanWindow | Constructor
__resizeColumns | Private method to resize the columns of the result list.
__resort | Private method to resort the devices list.
scanDevices | Public slot to ask the device for a Bluetooth scan and display the result.

### Static Methods

None

#### BluetoothScanWindow (Constructor)

BluetoothScanWindow(device, parent=None)

Constructor

device (BaseDevice)
  reference to the connected device
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### BluetoothScanWindow.__resizeColumns

__resizeColumns()

Private method to resize the columns of the result list.

#### BluetoothScanWindow.__resort

__resort()

Private method to resort the devices list.

#### BluetoothScanWindow.scanDevices

scanDevices()

Public slot to ask the device for a Bluetooth scan and display the result.

Up